/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.agents.serviceproviders.innovation;

import java.util.UUID;

/**
 * This class represents the innovations of our economy.
 * @author    Martin
 */
public abstract class Innovation {
	/**A static variable for "value adding" services*/
	public final static int VALUEADDING = 0;
	/**A static variable for services with network effects*/
	public final static int NETEFFADDING = 1;
	
	
	/** The network effect of the innovation. */
	protected double neteffect;
	/**The direct value of the innovation */
	protected double value;

	/**
	 * The unique ID of the innovation
	 */
	private String uniqueID;

	
	/**
	 * The basic constructor of an innovation.
	 * 
	 */
	public Innovation(){
		neteffect = 0;
		value = 0;
		uniqueID = UUID.randomUUID().toString();
	}

	
	/**
	 * Method to be used if the innovation produces network effects
	 * @return the network effect produced by this innovation
	 */
	public double getNetEffect(){
		return neteffect;
	}
	
	
	/**
	 * Method to get the type of innovation this is
	 * @return either NETEFFADDING or VALUEADDING (the int values)
	 */
	public abstract int getType();
	
	/**
	 * Method to get the unique ID of the innovation
	 * @return    the uniqueID
	 */
	public String getUniqueID(){
		return uniqueID;
	}
	
	/**
	 * Method to be used if the innovation produces direct value
	 * @return the value this innovation adds to the basic subscription (a percentage)
	 */
	public double getValueAdd(){
		return value;
	}
	
	
	
}
