/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.basicfunctionality;

import java.io.*;
import java.net.MalformedURLException;
import java.net.URL;
import org.w3c.dom.*;

/**
 * A reader and writer of the xml configuration file
 * 
 */
public class XMLConfigFile {


	/**
	 * The constructor
	 */
	public XMLConfigFile() {
	}

	/**
	 * Method to read from configuration file
	 * 
	 * @param moduleName
	 *            name of module
	 * 
	 * @return XML Document representing the properties
	 */
	public Document readConfFile(final String moduleName) {
		Document doc = null;
		if (moduleName != null && !moduleName.equals("")) {
			final String fileName = CONFIG_FILES_PATH + moduleName + ".xml";
			try {
				final File file = new File(fileName);
				final String fileUrl = CreateURL(file);
				final javax.xml.parsers.DocumentBuilderFactory dFactory =
					javax.xml.parsers.DocumentBuilderFactory.newInstance();
				final javax.xml.parsers.DocumentBuilder builder = dFactory.newDocumentBuilder();
				doc = builder.parse(fileUrl);
				final File f = new File(fileName);
				Config.getInstance().setLastModified(f.lastModified());
			} catch (final Exception e) {
				System.out.println(
						"Problem reading property file: " + e.toString());
			}

		}
		return doc;
	}


	/**
	 * Method used to check whether the file is changed during program execution. 
	 * 
	 * @param moduleName
	 *            name of the module
	 * 
	 * @return The last time the configuration file was changed
	 */
	public long getLastModified(final String moduleName) {
		long timeStamp = 0;
		final String fileName = CONFIG_FILES_PATH + moduleName + ".xml";
		try {
			final File f = new File(fileName);
			timeStamp = f.lastModified();
		} catch (final Exception e) {
			System.out.println("Could not read last time the file was changed");
		}
		return timeStamp;
	}

	/**
	 * Setting where the config is to be read from
	 * 
	 * @param path
	 *            File path of configuration file
	 */
	public synchronized void setConfigPath(final String path) {
		CONFIG_FILES_PATH = path + System.getProperty("file.separator");
		System.out.println("Searching for config file in: \n"+CONFIG_FILES_PATH);
	}


	/**
	 * Method to ensure a correct URL
	 * 
	 * @param file
	 *            the file to access
	 * 
	 * @return the string containing a legal URL
	 */
	private String CreateURL(final File file){
		String path = file.getAbsolutePath();
		try{
			return (new URL(path)).toString();
		}
		catch (final MalformedURLException ex){
			final String fs = System.getProperty("file.separator");
			final char sep = fs.charAt(0);
			if (sep != '/') {
				path = path.replace(sep, '/');
			}
			if (path.charAt(0) != '/') {
				path = '/' + path;
			}
			return "file://" + path;
		}
	}


	/** The CONFIG FILE PATH. */
	private static String CONFIG_FILES_PATH = "";

}