/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.communication;


import edu.ntnu.ecosim.basicfunctionality.Config;
import edu.ntnu.ecosim.basicfunctionality.Log;
import edu.ntnu.ecosim.management.SimulationManager;
import java.io.Serializable;
import org.w3c.dom.Document;

/**
 * The Class EcoSim. This is the interface toward the simulator, and is used to
 * setup, start, stop and reset the simulation.
 */
public class EcoSim implements Serializable{
	
	/** An auto-generated serial version UniqueID to enable serialization. */
	private static final long serialVersionUID = 3839992804697961779L;
	
	
	/** The simulation manager to be used. */
	private SimulationManager sm;

	/**
	 * The Constructor.
	 * 
	 * @param rr
	 *            the ResultReceiver to respond to
	 */
	public EcoSim(ResultReceiver rr){
		sm = new SimulationManager();
		sm.addObserver(rr);
		Log.getInstance().writeToLog("Initiating communication",Log.INFO);
	}
	
	
	/**
	 * The Constructor to be used by external applications that need to define the 
	 * file path of the configuration file.
	 * - This is the preferred constructor - 
	 * 
	 * @param rr
	 *            the ResultReceiver to respond to
	 * @param configpath
	 *            the file path to the configuration file
	 */     
	public EcoSim(ResultReceiver rr, String configpath){
		sm = new SimulationManager();
		sm.addObserver(rr);
		Config.getInstance().setConfigPath(configpath);
		Log.getInstance().writeToLog("Initiating communication",Log.INFO);
	}
	
	
	/**
	 * Setup the simulator.
	 * 
	 * @param setup
	 *            the Document containing setup information
	 */
	public void setupSim(Document setup){
		sm.setupEnvironment(setup);
		//Creates a thread to avoid tight coupling with the external application.
		Thread t = new Thread(sm);
		t.start();
	}
	
	/**
	 * Start the simulator.
	 */
	public void startSim(){
		sm.startSimulation();
	}
	
	/**
	 * Stop the simulator.
	 */
	public void stopSim(){
		sm.stopSimulation();
	}
	
	/**
	 * Reset the simulator.
	 */
	public void resetSim(){
		sm.reset();
		Runtime r = Runtime.getRuntime();
		r.gc();
	}




	
	
}
