/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.communication;

import java.util.Observable;
import java.util.Observer;
import org.w3c.dom.Document;
import edu.ntnu.ecosim.basicfunctionality.Log;

/**
 * This is an abstract class that must be implemented to receive the results
 * from the simulator. 
 */
public abstract class ResultReceiver implements Observer{
	


	/* (non-Javadoc)
	 * @see java.util.Observer#update(java.util.Observable, java.lang.Object)
	 */
	public void update(Observable obj, Object arg) {
		if(arg instanceof Document){
			final Document received = (Document)arg;
			xmlReceived(received);
		}
		else{
			Log.getInstance().writeToLog(ResultReceiver.class+"Received strange results", Log.ERROR);
		}
		
	}

	/**
	 * This method is called when a XML document is received. The implementation
	 * should parse the received document and use/display the results
	 * 
	 * @param doc
	 *            the document with information
	 */
	public abstract void xmlReceived(Document doc);
	
}
