/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.environment;

/**
 * The clock governs the main thread of the simulation. 
 * This is where each new time step is executed from.
 */
public class Clock extends Thread{

	/**
	 * The current time.
	 */
	private int time;
	
	/** A boolean telling whether the clock should be running. */
	private boolean isRunning = false;
	
	/** The market of the clock */
	private Market market;
	
	
	/**
	 * The Constructor.
	 * @param market the market the clock shall operate on
	 */
	protected Clock(final Market market){
		time = 0;
		this.market = market; 
	}
	
	
	
	/**
	 * Gets the time.
	 * @return         the current time
	 */
	protected int getTime(){
		return time;
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Thread#run()
	 */
	@Override
	public void run(){
		isRunning = true;
		
		while((time<market.getTimeToRun())&&isRunning){
			time++;
			market.newTimeStep();
			try {
				sleep(market.getSimulationSpeed());
			} catch (final InterruptedException e) {
			}
		}
		market.simulationDone();
	}
	
	
	/**
	 * Stops the clock.
	 */
	protected void stopClock(){
		isRunning = false;
	}
	
}
