/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.visual;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.NumberFormat;
import java.util.ArrayList;
import javax.swing.JSlider;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;


/**
 * This class allows for configuration of service provider properties
 * @author     martin.andreas.borke
 */
public class ConfigPanel2 extends javax.swing.JPanel implements ActionListener, ChangeListener{

	/** The serialVersionUID, used for serializetion purposes. */
	private static final long serialVersionUID = -2445666161368121911L;

	/** The number of added Service Providers. */
	int nofSP;

	/** The providers that are added. */
	ArrayList<String[]> providers;

	/** The main class (Visual) that this panel is added upon. */
	Visual visual;
	
	/** Statistically found averages of innovation launch time */
	private final static double[] timeAvg = {5.2, 5.4, 5.7, 6.4, 7.6, 8.5, 10, 13, 16, 29, 1000}; 

	/**
	 * The number of consumers.
	 */
	int nofConsumers;

	//Graphical variables
    private javax.swing.JTextField atbi;
    private javax.swing.JTextField bindfee;
    private javax.swing.JSlider ecoflex;
    private javax.swing.JLabel ecoflexlabel;
    private javax.swing.JTextField initsub;
    private javax.swing.JSlider innostrength;
    private javax.swing.JLabel innostrengthlabel;
    private javax.swing.JButton jButton1;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel10;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JSeparator jSeparator1;
    private javax.swing.JSeparator jSeparator2;
    private javax.swing.JSeparator jSeparator3;
    private javax.swing.JTextArea jTextArea1;
    private javax.swing.JTextField mapridec;
    private javax.swing.JTextField name;
    private javax.swing.JCheckBox predator;
    private javax.swing.JComboBox strategy;
    private javax.swing.JTextField subcost;
    private javax.swing.JSlider typeSlider;
    private javax.swing.JLabel typeSliderLabel;
    private javax.swing.JLabel typeSliderLabel1;
    private javax.swing.JLabel typeSliderLabel2;

    
	/**
	 * Creates new form ConfigPanel2.
	 * 
	 * @param v
	 *            the main class (Visual) that this panel is added to
	 */
	public ConfigPanel2(final Visual v) {
		providers  = new ArrayList<String[]>();
		initComponents();
		nofSP = 1;
		visual = v;
		nofConsumers = 0;
	}

	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(final ActionEvent e) {
		if ("addProvider".equals(e.getActionCommand())) {
			String infostring = "##################################\n";
			final String[] pro = new String[8];
			pro[0]=name.getText();
			infostring+="Name: "+name.getText()+"\n";
			pro[1] =  initsub.getText();
			infostring+="Initial subscribers: "+initsub.getText()+"\n";
			pro[2] = bindfee.getText();
			infostring+="Binding fee (initial): "+bindfee.getText()+"\n";
			pro[3] = subcost.getText();
			infostring+="Subscription cost (initial): "+subcost.getText()+"\n";
			pro[4] = parseStratName(strategy.getSelectedItem().toString());
			infostring+="Strategy: "+pro[4]+"\n";
			int ecofl = ecoflex.getValue();
			if(predator.isSelected()&&ecofl==10) {
				ecofl=20;
			}
			pro[5] = ecofl+"";
			pro[6] = innostrength.getValue()+"";
			if("INNOVATIVE".equals(pro[4])||"INNOREACTIVE".equals(pro[4])) infostring+="Innovative Strength: "+pro[6]+"\n";
			if("REACTIVE".equals(pro[4])||"INNOREACTIVE".equals(pro[4])) infostring+="Economic flexibility: "+ecoflex.getValue()+"\n";
			if(ecofl==20) {
				infostring+="This provider has predator behavior.\n";
			}
			pro[7] = typeSlider.getValue()+"";
			if("INNOVATIVE".equals(pro[4])||"INNOREACTIVE".equals(pro[4])) infostring+="Innovation type: "+(10*typeSlider.getValue())+"% network effects \n";
			providers.add(pro);
			nofConsumers+=Integer.parseInt(pro[1]);
			final String subs = jTextArea1.getText();
			jTextArea1.setText(subs+infostring);
			nofSP++;
			name.setText("Company "+nofSP);
			bindfee.setText(""+100);
			subcost.setText(""+100);
			initsub.setText("10000");
			ecoflex.setValue(5);
			innostrength.setValue(5);
			typeSlider.setValue(5);
			visual.spAdded();
			this.repaint();
		}	
		else if("strategyChanged".equals(e.getActionCommand())){
			final int strat = strategy.getSelectedIndex();
			switch(strat){
			case 0:
				innostrength.setVisible(false);
				innostrengthlabel.setVisible(false);
				ecoflex.setVisible(false);
				ecoflexlabel.setVisible(false);
				predator.setVisible(false);
				disableEcoHelp();
				disableInnoHelp();
				disableTypeSlider();
				disableHorLines();
				break;
			case 1:
				innostrength.setVisible(true);
				innostrengthlabel.setVisible(true);
				ecoflex.setVisible(false);
				ecoflexlabel.setVisible(false);
				predator.setVisible(false);
				disableEcoHelp();
				enableInnoHelp();
				disableHorLines();
				enableTypeSlider();
				break;
			case 2:
				innostrength.setVisible(false);
				innostrengthlabel.setVisible(false);
				ecoflex.setVisible(true);
				ecoflexlabel.setVisible(true);
				predator.setVisible(true);
				predator.setEnabled(false);
				disableInnoHelp();
				enableEcoHelp();
				disableHorLines();
				disableTypeSlider();
				break;
			case 3:
				innostrength.setVisible(true);
				innostrengthlabel.setVisible(true);
				ecoflex.setVisible(true);
				ecoflexlabel.setVisible(true);
				predator.setVisible(true);
				predator.setEnabled(false);
				enableInnoHelp();
				enableEcoHelp();
				enableHorLines();
				enableTypeSlider();
				break;
			default:
				break;
			}
		}
	}

	
	/**
	 * Gets the number of consumers that are added through this panel.
	 * @return    the number of consumers
	 */
	public int getNofConsumers(){
		return nofConsumers;
	}

	/**
	 * Gets the added providers.
	 * @return  ArrayList with information about the added providers. Each entry in the list contains an Array with [name, initial subscribers, binding fee, subscription cost, strategy name, economic flexibility, innovative strength, innovation type]
	 */
	public ArrayList<String[]> getProviders(){
		return providers;
	}

	/**
	 * Initialization of the components.
	 */
	private void initComponents() {
	       	jLabel1 = new javax.swing.JLabel();
	        jLabel2 = new javax.swing.JLabel();
	        name = new javax.swing.JTextField();
	        jLabel3 = new javax.swing.JLabel();
	        initsub = new javax.swing.JTextField();
	        jLabel4 = new javax.swing.JLabel();
	        bindfee = new javax.swing.JTextField();
	        jLabel5 = new javax.swing.JLabel();
	        subcost = new javax.swing.JTextField();
	        jScrollPane1 = new javax.swing.JScrollPane();
	        jTextArea1 = new javax.swing.JTextArea();
	        jButton1 = new javax.swing.JButton();
	        jLabel6 = new javax.swing.JLabel();
	        strategy = new javax.swing.JComboBox();
	        innostrengthlabel = new javax.swing.JLabel();
	        innostrength = new javax.swing.JSlider();
	        ecoflex = new javax.swing.JSlider();
	        ecoflexlabel = new javax.swing.JLabel();
	        predator = new javax.swing.JCheckBox();
	        jLabel7 = new javax.swing.JLabel();
	        atbi = new javax.swing.JTextField();
	        mapridec = new javax.swing.JTextField();
	        jLabel8 = new javax.swing.JLabel();
	        jLabel9 = new javax.swing.JLabel();
	        jLabel10 = new javax.swing.JLabel();
	        typeSliderLabel = new javax.swing.JLabel();
	        typeSlider = new javax.swing.JSlider();
	        typeSliderLabel1 = new javax.swing.JLabel();
	        typeSliderLabel2 = new javax.swing.JLabel();
	        jSeparator1 = new javax.swing.JSeparator();
	        jSeparator2 = new javax.swing.JSeparator();
	        jSeparator3 = new javax.swing.JSeparator();

	        jLabel1.setFont(new java.awt.Font("Tahoma", 1, 14));
	        jLabel1.setText("Company configuration");

	        jLabel2.setText("Name");

	        name.setHorizontalAlignment(javax.swing.JTextField.TRAILING);

	        jLabel3.setText("Initial Subscribers");

	        initsub.setHorizontalAlignment(javax.swing.JTextField.TRAILING);

	        jLabel4.setText("Binding Fee (initial)");

	        bindfee.setHorizontalAlignment(javax.swing.JTextField.TRAILING);

	        jLabel5.setText("Subscription Fee (initial)");

	        subcost.setHorizontalAlignment(javax.swing.JTextField.TRAILING);

	        jScrollPane1.setEnabled(false);
	        jTextArea1.setColumns(20);
	        jTextArea1.setEditable(false);
	        jTextArea1.setRows(5);
	        jScrollPane1.setViewportView(jTextArea1);

	        jButton1.setText("Add Provider");

	        jLabel6.setText("Strategy");

	        strategy.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "None", "Innovating", "Reactive", "Both" }));

	        innostrengthlabel.setText("Innovative Strength");

	        innostrength.setMaximum(10);
	        innostrength.setMinorTickSpacing(1);
	        innostrength.setPaintTicks(true);
	        innostrength.setSnapToTicks(true);
	        innostrength.setValue(5);

	        ecoflex.setMaximum(10);
	        ecoflex.setMinorTickSpacing(1);
	        ecoflex.setPaintTicks(true);
	        ecoflex.setSnapToTicks(true);
	        ecoflex.setValue(5);

	        ecoflexlabel.setText("Economic Flexibility");

	        predator.setText("Allow predator behavior");
	        predator.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
	        predator.setMargin(new java.awt.Insets(0, 0, 0, 0));

	        jLabel7.setFont(new java.awt.Font("Tahoma", 2, 11));
	        jLabel7.setText("Average time between innovations: ");

	        atbi.setEditable(false);
	        atbi.setHorizontalAlignment(javax.swing.JTextField.CENTER);

	        mapridec.setEditable(false);
	        mapridec.setHorizontalAlignment(javax.swing.JTextField.CENTER);

	        jLabel8.setFont(new java.awt.Font("Tahoma", 2, 11));
	        jLabel8.setText("Maximal price decrease each month:");

	        jLabel9.setFont(new java.awt.Font("Tahoma", 2, 11));
	        jLabel9.setText("months");

	        jLabel10.setFont(new java.awt.Font("Tahoma", 2, 11));
	        jLabel10.setText("% of current");

	        typeSliderLabel.setText("Type of innovativeness");

	        typeSlider.setMaximum(10);
	        typeSlider.setMinorTickSpacing(1);
	        typeSlider.setPaintTicks(true);
	        typeSlider.setSnapToTicks(true);
	        typeSlider.setValue(5);

	        typeSliderLabel1.setText("Add value");

	        typeSliderLabel2.setText("Add network effects");
	        
	        //Methods to tweak the user interface
			predator.setVisible(false);
			predator.setEnabled(false);
			ecoflexlabel.setVisible(false);
			ecoflex.setVisible(false);
			ecoflex.setName("ecoflex");
			innostrengthlabel.setVisible(false);
			innostrength.setVisible(false);
			innostrength.setName("innostrength");
			innostrength.addChangeListener(this);
			ecoflex.addChangeListener(this);
			strategy.setActionCommand("strategyChanged");
			strategy.addActionListener(this);
			
			//Setting tool tip texts
			predator.setToolTipText("Predator behavior means that this provider will "+
					"try to up to 80% of the market through price strategies. "+
					"This option is only available at maximum economic "+
			"flexibility.");
			name.setToolTipText("Here you can specify the name of the service provider.");
			bindfee.setToolTipText("The binding fee is the initial price (ont-time) that a consumer must pay to subscribe to the provider.");
			initsub.setToolTipText("The initial subscribers are the installed base that this service provider has at time zero.");
			subcost.setToolTipText("The subscription fee is the monthly price that the consumer must pay to subscribe to the provider.");
			strategy.setToolTipText("Select a strategy for the service provider, or none if it shall behave statically");
			ecoflex.setToolTipText("The economic flexibility describes how much the service provider is able to change its prices");
			innostrength.setToolTipText("The innovative strength describes how innovative the company is (how often it is enabled to produce innovations).");
			typeSlider.setToolTipText("This slider is used to select what kind of innovations are to be developed. The further to the right, the more of the innovations have network effects");
			jButton1.setToolTipText("Add the specified provider to the market");
			
			name.setText("Company 1");
			initsub.setText("10000");
			bindfee.setText("100");
			subcost.setText("100");
			disableEcoHelp();
			disableInnoHelp();
			jButton1.setActionCommand("addProvider");
			jButton1.addActionListener(this);
			atbi.setEnabled(false);
			mapridec.setEnabled(false);
			disableTypeSlider();
			disableHorLines();
			
			//Autogenerated layout code from NetBeans, do not modify!
	        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
	        this.setLayout(layout);
	        layout.setHorizontalGroup(
	            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
	            .addGroup(layout.createSequentialGroup()
	                .addGap(37, 37, 37)
	                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
	                    .addComponent(jLabel1)
	                    .addGroup(layout.createSequentialGroup()
	                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
	                            .addGroup(layout.createSequentialGroup()
	                                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
	                                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, layout.createSequentialGroup()
	                                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
	                                            .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
	                                                .addComponent(jLabel2)
	                                                .addComponent(jLabel3)
	                                                .addComponent(jLabel4)
	                                                .addComponent(jLabel5, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
	                                                .addComponent(jLabel6)
	                                                .addComponent(innostrengthlabel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
	                                            .addComponent(ecoflexlabel)
	                                            .addComponent(typeSliderLabel))
	                                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
	                                            .addGroup(layout.createSequentialGroup()
	                                                .addGap(18, 18, 18)
	                                                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
	                                                    .addComponent(predator, javax.swing.GroupLayout.DEFAULT_SIZE, 260, Short.MAX_VALUE)
	                                                    .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
	                                                        .addComponent(innostrength, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
	                                                        .addComponent(strategy, javax.swing.GroupLayout.Alignment.LEADING, 0, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
	                                                        .addComponent(subcost, javax.swing.GroupLayout.Alignment.LEADING)
	                                                        .addComponent(bindfee, javax.swing.GroupLayout.Alignment.LEADING)
	                                                        .addComponent(initsub, javax.swing.GroupLayout.Alignment.LEADING)
	                                                        .addComponent(name, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 202, Short.MAX_VALUE))
	                                                    .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
	                                                        .addComponent(typeSlider, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
	                                                        .addComponent(ecoflex, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))))
	                                            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
	                                                .addGap(5, 5, 5)
	                                                .addComponent(typeSliderLabel1)
	                                                .addGap(104, 104, 104)
	                                                .addComponent(typeSliderLabel2)
	                                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 23, Short.MAX_VALUE))))
	                                    .addComponent(jButton1, javax.swing.GroupLayout.Alignment.LEADING))
	                                .addGap(147, 147, 147))
	                            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
	                                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
	                                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, layout.createSequentialGroup()
	                                        .addComponent(jLabel7)
	                                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                                        .addComponent(atbi, javax.swing.GroupLayout.DEFAULT_SIZE, 135, Short.MAX_VALUE))
	                                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, layout.createSequentialGroup()
	                                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                                        .addComponent(jLabel8)
	                                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                                        .addComponent(mapridec, javax.swing.GroupLayout.DEFAULT_SIZE, 135, Short.MAX_VALUE)))
	                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
	                                    .addComponent(jLabel10)
	                                    .addComponent(jLabel9))
	                                .addGap(160, 160, 160))
	                            .addComponent(jSeparator1, javax.swing.GroupLayout.DEFAULT_SIZE, 539, Short.MAX_VALUE)
	                            .addComponent(jSeparator2, javax.swing.GroupLayout.DEFAULT_SIZE, 539, Short.MAX_VALUE)
	                            .addComponent(jSeparator3, javax.swing.GroupLayout.DEFAULT_SIZE, 539, Short.MAX_VALUE))
	                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                        .addComponent(jScrollPane1, javax.swing.GroupLayout.PREFERRED_SIZE, 302, javax.swing.GroupLayout.PREFERRED_SIZE)
	                        .addGap(237, 237, 237)))
	                .addGap(99, 99, 99))
	        );
	        layout.setVerticalGroup(
	            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
	            .addGroup(layout.createSequentialGroup()
	                .addContainerGap()
	                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
	                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, layout.createSequentialGroup()
	                        .addGap(46, 46, 46)
	                        .addComponent(jScrollPane1, javax.swing.GroupLayout.PREFERRED_SIZE, 431, javax.swing.GroupLayout.PREFERRED_SIZE))
	                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, layout.createSequentialGroup()
	                        .addComponent(jLabel1)
	                        .addGap(22, 22, 22)
	                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
	                            .addComponent(jLabel2)
	                            .addComponent(name, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
	                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
	                            .addComponent(jLabel3)
	                            .addComponent(initsub, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
	                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
	                            .addComponent(jLabel4)
	                            .addComponent(bindfee, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
	                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
	                            .addComponent(jLabel5)
	                            .addComponent(subcost, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
	                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
	                            .addComponent(jLabel6)
	                            .addComponent(strategy, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
	                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                        .addComponent(jSeparator2, javax.swing.GroupLayout.PREFERRED_SIZE, 10, javax.swing.GroupLayout.PREFERRED_SIZE)
	                        .addGap(9, 9, 9)
	                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
	                            .addComponent(innostrengthlabel)
	                            .addComponent(innostrength, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
	                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
	                            .addGroup(layout.createSequentialGroup()
	                                .addGap(12, 12, 12)
	                                .addComponent(typeSliderLabel)
	                                .addGap(14, 14, 14)
	                                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
	                                    .addComponent(typeSliderLabel2)
	                                    .addComponent(typeSliderLabel1)))
	                            .addGroup(layout.createSequentialGroup()
	                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                                .addComponent(typeSlider, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
	                        .addGap(7, 7, 7)
	                        .addComponent(jSeparator1, javax.swing.GroupLayout.PREFERRED_SIZE, 10, javax.swing.GroupLayout.PREFERRED_SIZE)
	                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
	                            .addGroup(layout.createSequentialGroup()
	                                .addComponent(ecoflex, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
	                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                                .addComponent(predator))
	                            .addComponent(ecoflexlabel))
	                        .addGap(13, 13, 13)
	                        .addComponent(jSeparator3, javax.swing.GroupLayout.PREFERRED_SIZE, 10, javax.swing.GroupLayout.PREFERRED_SIZE)
	                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
	                            .addComponent(jLabel7)
	                            .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
	                                .addComponent(jLabel9)
	                                .addComponent(atbi, javax.swing.GroupLayout.PREFERRED_SIZE, 20, javax.swing.GroupLayout.PREFERRED_SIZE)))
	                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
	                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
	                            .addComponent(mapridec, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
	                            .addComponent(jLabel10)
	                            .addComponent(jLabel8))
	                        .addGap(41, 41, 41)
	                        .addComponent(jButton1)))
	                .addGap(75, 75, 75))
	        );
	}

	
	/**
	 * Method to disable the horizontal separator lines
	 *
	 */
	private void disableHorLines(){
		jSeparator1.setVisible(false);
		jSeparator2.setVisible(false);
		jSeparator3.setVisible(false);
	}
	
	/**
	 * Method to enable the horizontal separator lines
	 *
	 */
	private void enableHorLines(){
		jSeparator1.setVisible(true);
		jSeparator2.setVisible(true);
		jSeparator3.setVisible(true);
	}
	
	/**
	 * Method to disable the "type" slider
	 *
	 */
	private void disableTypeSlider(){
		typeSlider.setVisible(false);
		typeSliderLabel.setVisible(false);
		typeSliderLabel1.setVisible(false);
		typeSliderLabel2.setVisible(false);
	}
	
	/**
	 * Method to enable the "type" slider
	 *
	 */
	private void enableTypeSlider(){
		typeSlider.setVisible(true);
		typeSliderLabel.setVisible(true);
		typeSliderLabel1.setVisible(true);
		typeSliderLabel2.setVisible(true);
	}
	
	/**
	 * Method to disable support information about innovativeness
	 *
	 */
	private void disableInnoHelp(){
		jLabel7.setVisible(false);
		jLabel9.setVisible(false);
		atbi.setVisible(false);
	}

	/**
	 * Method to enable support information about innovativeness
	 *
	 */
	private void enableInnoHelp(){
		jLabel7.setVisible(true);
		jLabel9.setVisible(true);
		atbi.setText(calculateAvgInnoTime(innostrength.getValue()));
		atbi.setVisible(true);
		
	}

	/**
	 * Method to disable support information about economic flexibility
	 *
	 */
	private void disableEcoHelp(){
		jLabel8.setVisible(false);
		jLabel10.setVisible(false);
		mapridec.setVisible(false);
	}

	/**
	 * Method to enable support information about economic flexibility
	 *
	 */
	private void enableEcoHelp(){
		mapridec.setText(calculatePriceDecrease(ecoflex.getValue()));
		jLabel8.setVisible(true);
		jLabel10.setVisible(true);
		mapridec.setVisible(true);
	}

	/**
	 * Parses the strategy name.
	 * 
	 * @param strat
	 *            the strategy
	 * 
	 * @return a string with the representation required from the simulator
	 */
	private String parseStratName(final String strat){
		if(strat.equals("None")) {
			return "NONE";
		} else if(strat.equals("Innovating")) {
			return "INNOVATIVE";
		} else if(strat.equals("Reactive")) {
			return "REACTIVE";
		} else {
			return "INNOREACTIVE";
		}
	}

	/* (non-Javadoc)
	 * @see javax.swing.event.ChangeListener#stateChanged(javax.swing.event.ChangeEvent)
	 */
	public void stateChanged(final ChangeEvent e) {
		final JSlider source = (JSlider)e.getSource();
		if (!source.getValueIsAdjusting()) {
			if(source.getName().equals("ecoflex")){
				final int val = source.getValue();
				if(val==10) {
					predator.setEnabled(true);
				} else{
					predator.setEnabled(false);
					predator.setSelected(false);
				}
				mapridec.setText(calculatePriceDecrease(val));
				mapridec.repaint();
			}
			else if(source.getName().equals("innostrength")){
				atbi.setText(calculateAvgInnoTime(source.getValue()));
				atbi.repaint();
			}
		}
	}
	
	/**
	 * Method to calculate the maximum monthly price decrease (according to internal rules in the simulator)
	 * @param strength the economic strength set in the simulator
	 * @return the max. monthly price decrease
	 */
	private String calculatePriceDecrease(int strength){
		double r = (double)strength/2;
		NumberFormat nf = NumberFormat.getInstance();
		nf.setMaximumFractionDigits(1);
		nf.setMinimumFractionDigits(1);
		return nf.format(r);
	}
	
	/**
	 * Method to calculate the average time between innovation launches
	 * according to internal rules of the simulator.
	 * 
	 * Currently, the averages are calculated based on statistic results from
	 * the simulator.
	 * 
	 * @param strength the innovative strength of the provider
	 * @return the avg. months between innovation launches
	 */
	private String calculateAvgInnoTime(int strength){
		double a = timeAvg[10-strength];
		NumberFormat nf = NumberFormat.getInstance();
		nf.setMaximumFractionDigits(1);
		nf.setMinimumFractionDigits(1);
		return nf.format(a);
	}

	/**
	 * Method called to freeze further configuration when the simulation starts
	 *
	 */
	public void freeze() {
		jButton1.setEnabled(false);
	}
	
	/**
	 * This method can be used to clear all the added providers
	 *
	 */
	public void clearProviders(){
		nofConsumers = 0;
		providers = null;
		providers = new ArrayList<String[]>();
		jTextArea1.setText("");
	}

}
