/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.visual;

import javax.swing.SwingConstants;

/**
 * Class used for configuration of environment variables
 * 
 * @author martin.andreas.borke
 */
public class EnvironmentPanel2 extends javax.swing.JPanel {
    

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -3820303388425857033L;
	                  
  
	private javax.swing.JTextField initpop;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
	private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JTextField runs;
    private javax.swing.JTextField simlength;
    private javax.swing.JSlider speedSlide;
    
    /**
	 * Creates new form EnvironmentPanel.
	 */
    public EnvironmentPanel2() {
        initComponents();
    }
    
    /**
	 * Calculate the slider value.
	 * 
	 * @return the value of the slider governing the speed of simulation
	 */
    private int calculateSliderValue() {
		final int level = speedSlide.getValue();
		return (1000-(level*10)+1);
	}
    
    /**
	 * Gets the number of consumers.
	 * 
	 * @return the number of consumers
	 */
    public int getNofConsumers(){
    	return Integer.parseInt(initpop.getText());
    }
    
    /**
	 * Gets the total time that shall be simulated
	 * 
	 * @return the total time
	 */
    public int getTotalTime(){
    	return Integer.parseInt(simlength.getText());
    }
    
    /**
     * Gets the number of runs (simulations of the same scenario)
     * @return the number of runs
     */
    public int getNumberOfRuns(){
    	return Integer.parseInt(runs.getText());
    }
    
    /**
     * Method to avoid further configuration after the simulation is started
     *
     */
    public void freeze(){
    	initpop.setEditable(false);
    	runs.setEditable(false);
    	simlength.setEditable(false);
    	speedSlide.setEnabled(false);
    }
    
  
    /**
	 * Gets the configured variables.
	 * 
	 * @return the configured variables
	 */
    public String[] getVariables(){
    	final String[] retur = new String[3];
    	retur[0] = initpop.getText();
    	retur[1] = simlength.getText();
    	retur[2] = ""+calculateSliderValue();
    	return retur;
    }
  
    
    /**
     * Method to initialize the components of the panel
     */
    private void initComponents() {
        jLabel1 = new javax.swing.JLabel();
        jLabel2 = new javax.swing.JLabel();
        initpop = new javax.swing.JTextField();
        jLabel3 = new javax.swing.JLabel();
        jLabel4 = new javax.swing.JLabel();
        jLabel5 = new javax.swing.JLabel();
        speedSlide = new javax.swing.JSlider();
        simlength = new javax.swing.JTextField();
        jLabel6 = new javax.swing.JLabel();
        jLabel7 = new javax.swing.JLabel();
        jLabel8 = new javax.swing.JLabel();
        jLabel9 = new javax.swing.JLabel();
        runs = new javax.swing.JTextField();
        
        
        jLabel1.setFont(new java.awt.Font("Tahoma", 1, 14));
        jLabel1.setText("Environment Configuration");

        jLabel2.setText("Initial Population");

        initpop.setHorizontalAlignment(SwingConstants.TRAILING);
        initpop.setText("0");

        jLabel3.setText("Simulation Speed");

        jLabel4.setText("Simulation Length");

        jLabel5.setText("Persons");

        
        speedSlide.setMinimum(1);
        
        simlength.setHorizontalAlignment(SwingConstants.TRAILING);
        simlength.setText("48");
        
        jLabel6.setText("Months");

        jLabel7.setText("(slow)");

        jLabel8.setText("(fast)");

        jLabel9.setText("Number of runs ");
        runs.setText(""+1);
        runs.setHorizontalAlignment(SwingConstants.TRAILING);
        
        //Specifying tool tip texts
        initpop.setToolTipText("The initial population are the consumers not currently subscribing to a service provider when the simulation starts.");
        runs.setToolTipText("If more than one run is selected, the simulation will be run as many times as specified without further need for supervision.");
        simlength.setToolTipText("The number of months that are to be simulated.");
        speedSlide.setToolTipText("This slider influences how fast the simulations are to be run.");
        
        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addGap(53, 53, 53)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(jLabel3)
                        .addContainerGap())
                    .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                        .addGroup(layout.createSequentialGroup()
                            .addComponent(jLabel4)
                            .addContainerGap())
                        .addGroup(layout.createSequentialGroup()
                            .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                .addComponent(jLabel1)
                                .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                                    .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                        .addComponent(jLabel2)
                                        .addComponent(jLabel9))
                                    .addGap(39, 39, 39)
                                    .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                                        .addGroup(javax.swing.GroupLayout.Alignment.LEADING, layout.createSequentialGroup()
                                            .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                                                .addComponent(simlength, javax.swing.GroupLayout.Alignment.LEADING)
                                                .addComponent(initpop, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 100, Short.MAX_VALUE)
                                                .addComponent(runs, javax.swing.GroupLayout.Alignment.LEADING))
                                            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                            .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                                .addComponent(jLabel6)
                                                .addComponent(jLabel5)))
                                        .addComponent(speedSlide, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 200, Short.MAX_VALUE)
                                        .addGroup(javax.swing.GroupLayout.Alignment.LEADING, layout.createSequentialGroup()
                                            .addComponent(jLabel7)
                                            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 144, Short.MAX_VALUE)
                                            .addComponent(jLabel8)))
                                    .addGap(109, 109, 109)))
                            .addGap(507, 507, 507)))))
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addGap(23, 23, 23)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(jLabel1)
                        .addGap(35, 35, 35)
                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jLabel2)
                            .addComponent(initpop, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jLabel5))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jLabel4)
                            .addComponent(simlength, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jLabel6))
                        .addGap(12, 12, 12)
                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jLabel9)
                            .addComponent(runs, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addGap(24, 24, 24)
                        .addComponent(jLabel7))
                    .addComponent(jLabel8))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(jLabel3)
                    .addComponent(speedSlide, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap(279, Short.MAX_VALUE))
        );
    }                      
    
}