/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.visual.graph;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.geom.Line2D;
import java.util.ArrayList;

/**
 * The churn graph panel displays information about customer churn.
 */
public class ChurnGraphPanel extends GraphPanel{


	/** The Constant serialVersionUID, used for serializability */
	private static final long serialVersionUID = 1613574614686190785L;
	
	/** The value of this round for each provider. */
	private ArrayList<Integer> thisvalue;
	
	/** The total subscribers in the market. */
	int totalsubs;
	
	/** The number of providers. */
	int providers;


	/**
	 * The Constructor of this panel/graph
	 */
	public ChurnGraphPanel(){
		this.setBackground(background);
		lines = new ArrayList<GraphLine>();
		thisvalue = new ArrayList<Integer>();
		providers = 0;
		time = 0;
		totaltime = 0;
	}


	/**
	 * Adds a new provider.
	 * 
	 * @param name
	 *            the name of the provider
	 */
	public void addProvider(String name){
		int colorint = providers%colorlist.length;
		lines.add(new GraphLine(name,colorlist[colorint], 10, ((graphysize-10)/2)+10));
		thisvalue.add(Integer.valueOf(0));
		providers++;
	}

	/**
	 * Adds a new point to the graph
	 * 
	 * @param time
	 *            the time of the new point
	 * @param churnrate
	 *            the churnrate at this time
	 * @param provider
	 *            the providers place in the local arraylist
	 */
	public void addPoint(int provider, int time, double churnrate){
		if(this.time!=time){this.time=time;}
		int x = 10 + (int)(time*timestep);
		int y = (((graphysize-10)/2)+10)-(int)(churnrate*(graphysize-10)/2); 
		lines.get(provider).addPoint(x, y);
		thisvalue.set(provider, Integer.valueOf((int)(100*churnrate)));
	}





	/* (non-Javadoc)
	 * @see javax.swing.JComponent#paintComponent(java.awt.Graphics)
	 */
	public void paintComponent(Graphics comp){
		super.paintComponent(comp); 
		Graphics2D comp2D = (Graphics2D) comp; 
		comp2D.setColor(background); 
		comp2D.fillRect(0, 0, xsize, ysize); 

		comp2D.setColor(Color.black);
		float splitline = Float.parseFloat((((graphysize-10)/2)+10)+"F");
		float yl = Float.parseFloat((graphysize)+"F");
		float xl = Float.parseFloat((graphxsize)+"F");
		comp2D.draw(new Line2D.Float(10F,splitline,xl,splitline));
		comp2D.draw(new Line2D.Float(10F,yl,10F,10F));

		comp2D.drawString("Customer Churn", Float.parseFloat(((xsize/2)-30)+"F"), 20F);

		comp2D.drawString("TIME: "+time, Float.parseFloat(((xsize/2)-10)+"F"), 35F);

		if(totaltime!=0){
			int stepsize = (int)(((double)totaltime/10)*timestep);
			for(int i=1;i<11;i++){
				int xplace = 10+i*stepsize;
				float y1 = splitline-10F;
				float y2 = splitline;
				Float xfl = Float.parseFloat(xplace+"F");
				comp2D.draw(new Line2D.Float(xfl,y1,xfl,y2));
				String timstr = ""+(int)(((double)totaltime/10)*i);
				Float xfl2 = Float.parseFloat((xplace-5)+"F");
				comp2D.drawString(timstr,xfl2 , splitline+15F);
			}
		}
		double stepsize = ((double)(graphysize-10)/20);
		for(int i=0;i<21;i++){
			int yplace = (int)(graphysize-i*stepsize);
			float yfl = Float.parseFloat(yplace+"F");
			float x1 = 5F;
			float x2 = 15F;
			comp2D.draw(new Line2D.Float(x1,yfl,x2,yfl));
			int pct = i*10-100;
			String subStr = pct+" %";
			float yfl2 = Float.parseFloat((yplace+5)+"F");
			if(pct!=0) comp2D.drawString(subStr, 18F, yfl2);
		}



		for(int i=0;i<lines.size();i++){
			GraphLine gl = lines.get(i);
			comp2D.setColor(gl.getColor());
			String namex = (graphxsize+20)+"F";
			int inty = i*15 + 20;
			String namey = inty+"F";
			String stringToDraw = gl.getName()+":  "+thisvalue.get(i)+"%";
			comp2D.drawString(stringToDraw, Float.parseFloat(namex), Float.parseFloat(namey));
			ArrayList<Line2D.Float> lineList = gl.getLines();
			for(int j=0;j<lineList.size();j++){
				comp2D.draw(lineList.get(j));
			}
		}

	}

}
