/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.visual.graph;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.util.ArrayList;

/**
 * The Class ConsumerPiePanel is used to present information about each providers share
 * of the total market.
 */
public class ConsumerPiePanel extends GraphPanel{
	
	/** The Constant serialVersionUID is used for serialization */
	private static final long serialVersionUID = -5466015871065676411L;
	
	/** The subscriber list contains the number of subscribers for each provider. */
	private ArrayList<Integer> subscriberList;
	
	/** The providers names. */
	private ArrayList<String> providernames;
	
	/**
	 * The Constructor of the panel.
	 */
	public ConsumerPiePanel(){
		time = 0;
		this.setBackground(background);
		subscriberList = new ArrayList<Integer>();
		providernames = new ArrayList<String>();
		
	}
	
	/**
	 * Adds a new provider to the list
	 * 
	 * @param nofSubscribers
	 *            the number of subscribers to this provider
	 * @param name
	 *            the name of the provider
	 */
	public void addProvider(int nofSubscribers, String name){
		providernames.add(name);
		subscriberList.add(nofSubscribers);
	}
	
	/**
	 * Sets the number of subscribers for a specified provider
	 * 
	 * @param time
	 *            the time at which this occured
	 * @param nofSubscribers
	 *            the new number of subscribers
	 * @param provider
	 *            the providers place in the list
	 */
	public void setSubscribers(int provider, int nofSubscribers, int time){
		subscriberList.set(provider, nofSubscribers);
		if(this.time!=time){this.time=time;}
	}
	
	/* (non-Javadoc)
	 * @see javax.swing.JComponent#paintComponent(java.awt.Graphics)
	 */
	public void paintComponent(Graphics comp){
		super.paintComponent(comp); 
		Graphics2D comp2D = (Graphics2D) comp; 
		comp2D.setColor(background); 
		comp2D.fillRect(0, 0, xsize, ysize); 
		
		comp2D.setColor(Color.black);
		comp2D.drawString("Share of bound subscribers", 150F, 20F);
		comp2D.drawString("TIME: "+time, 170F, 35F);
		
		
		
		int totalsubsc = 0;
		for(int i =0;i<subscriberList.size();i++){
			totalsubsc+=subscriberList.get(i);
		}
		
		int[] degrees = new int[subscriberList.size()];
		for(int i=0;i<subscriberList.size();i++){
			degrees[i] = (int)Math.round((360*((double)subscriberList.get(i)/totalsubsc)));
		}
		
		int lastangle = 0;
		for(int i=0;i<providernames.size();i++){
			comp2D.setColor(colorlist[i%colorlist.length]);
			String namex = "10F";
			int inty = i*15 + 20;
			String namey = inty+"F";
			comp2D.drawString(providernames.get(i)+": "+subscriberList.get(i), Float.parseFloat(namex), Float.parseFloat(namey));
			
			comp2D.fillArc(120, 80, 250, 250, lastangle, degrees[i]);
			lastangle+=degrees[i];
		}
	}

}
