/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.visual.graph;

import java.awt.Color;
import java.awt.geom.Line2D;
import java.util.ArrayList;

/**
 * The Class GraphLine is used to represent the lines of the graph, which 
 * when taken together represent the graph of one provider
 * @author    martin.andreas.borke
 */
public class GraphLine {

	/** The last point. */
	private int[] lastPoint;
	
	/** The lines. */
	private ArrayList<Line2D.Float> lines;
	
	/** The color of the line. */
	private Color theColor;
	
	/**
	 * The name of the provider having this line/graph .
	 */
	private String name;
	
	/**
	 * The Constructor.
	 * 
	 * @param startx
	 *            the startposition at the x axis
	 * @param starty
	 *            the startposition at the y axis
	 * @param c
	 *            the color the provider should be drawn in
	 * @param name
	 *            the name of the provider
	 */
	public GraphLine(String name, Color c, int startx, int starty){
		this.name = name;
		lines = new ArrayList<Line2D.Float>();
		theColor = c;
		lastPoint = new int[2];
		lastPoint[0] = startx;
		lastPoint[1] = starty;
	}
	
	/**
	 * Adds a new point to the graphline
	 * 
	 * @param y
	 *            the y position
	 * @param x
	 *            the x position
	 */
	public void addPoint(int x, int y){
		Line2D.Float line= new Line2D.Float(generateFloat(lastPoint[0]), generateFloat(lastPoint[1]), generateFloat(x), generateFloat(y));
		lines.add(line);
		lastPoint[0] = x;
		lastPoint[1] = y;
	}
	
	
	/**
	 * Gets the lines of this graph
	 * @return   the lines
	 */
	public ArrayList<Line2D.Float> getLines(){
		return lines;
	}
	
	/**
	 * Generate float from integer.
	 * 
	 * @param fl
	 *            the float as integer
	 * 
	 * @return the float as float
	 */
	private float generateFloat(int fl){
		String flo =  fl+"F";
		return Float.parseFloat(flo);
	}
	
	/**
	 * Gets the color of this line
	 * 
	 * @return the color
	 */
	public Color getColor(){
		return theColor;
	}
	
	/**
	 * Gets the name of the provider having this line
	 * @return    the name
	 */
	public String getName(){
		return name;
	}
	
	
	
}
