/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.visual.graph;

import java.awt.Color;
import java.util.ArrayList;

import javax.swing.JPanel;

/**
 * The Class GraphPanel is an abstract class giving the necessary methods and parameters for a panel
 * displaying graphical information in the ecosim visual interface.
 */
public abstract class GraphPanel extends JPanel {

	/** The lines. */
	protected ArrayList<GraphLine> lines;
	
	/** The list of available colors. */
	protected final Color[] colorlist = {new java.awt.Color(20, 141, 163), Color.red, Color.yellow, new java.awt.Color(0, 255, 0), Color.blue,new java.awt.Color(72, 72, 84), new java.awt.Color(252, 143, 0), new java.awt.Color(255, 0, 204), new java.awt.Color(178, 0, 255)};
	
	/** The current time. */
	protected int time;
	
	/** The total time. */
	protected int totaltime;
	
	/** The size of one time step on the x axis. */
	protected double timestep;
	
	/** The background color. */
	protected Color background = new java.awt.Color(233, 241, 243);
	
	/** The horizontal size of the graph. */
	protected int xsize = 420;
	
	/** The vertical size of the graph. */
	protected int ysize = 320;
		
	/** The graphs x axis size. */
	protected int graphxsize = 450;
	
	/** The graphs y axis size. */
	protected int graphysize = 330;
	
	
	
	/**
	 * Sets the total time.
	 * 
	 * @param time
	 *            the total time
	 */
	public void setTotalTime(int time){
		timestep = (double)graphxsize/time;
		totaltime = time;
	}
	
}
