/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.visual.graph;

import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.util.ArrayList;

/**
 * The Class InnovationsPanel presents the number 
 * of innovations launched by each provider.
 */
public class InnovationsPanel extends GraphPanel {

	/** The Constant serialVersionUID is used for serialization purposes */
	private static final long serialVersionUID = 3378687641430732228L;
	
	/** The names of the providers. */
	private ArrayList<String> names;
	
	/** The number of innovations for each provider. */
	private ArrayList<Integer> innovations;
	
	/**
	 * The Constructor of the panel.
	 */
	public InnovationsPanel(){
		names = new ArrayList<String>();
		innovations = new ArrayList<Integer>();
		this.setBackground(background);
	}
	
	/**
	 * Adds a new provider to the panel
	 * 
	 * @param name
	 *            the name
	 */
	public void addProvider(String name){
		names.add(name);
		innovations.add(0);
	}
	
	/**
	 * Sets the number of innovations for the given provider.
	 * 
	 * @param nofInno
	 *            the number of innovations
	 * @param provider
	 *            the providers place in the local arraylist
	 */
	public void setNofInnovations(int provider, int nofInno){
		innovations.set(provider,nofInno);
	}
	
	/* (non-Javadoc)
	 * @see javax.swing.JComponent#paintComponent(java.awt.Graphics)
	 */
	public void paintComponent(Graphics comp){
		super.paintComponent(comp); 
		Graphics2D comp2D = (Graphics2D) comp; 
		comp2D.setColor(Color.BLACK);
		Font headFont = new Font("SansSerif", Font.BOLD, 16);
		comp2D.setFont(headFont);
		comp2D.drawString("Innovations: ", 10F, 30F);
		Font currentFont = new Font("SansSerif", Font.PLAIN, 14); 
		comp2D.setFont(currentFont);
		for(int i=0;i<names.size();i++){
			comp2D.setColor(colorlist[i%colorlist.length]);
			String namex = "10F";
			int inty = i*20 + 50;
			String namey = inty+"F";
			comp2D.drawString(names.get(i)+" has produced "+innovations.get(i) +" innovations", Float.parseFloat(namex), Float.parseFloat(namey));
		}
	}
	
}
