/*
 * EcoSim is developed by Martin Brke as a master thesis at NTNU
 * in cooperation with Accenture.
 * 
 * For more information, contact Martin Brke at martinb@stud.ntnu.no
 */
package edu.ntnu.ecosim.visual.graph;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.geom.Line2D;
import java.util.ArrayList;

/**
 * The revenue graph panel displays information about the total revenue of the companies.
 */
public class RevenueGraphPanel extends GraphPanel{
	
	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -7413317399278962546L;
	
	/** The providers. */
	private int providers;
	
	/** The totalsubs. */
	private int totalsubs;
	
	/** The max subscription cost. */
	private int maxSubscriptionCost;

	
	/**
	 * The Constructor.
	 */
	public RevenueGraphPanel(){
		this.setBackground(background);
		lines = new ArrayList<GraphLine>();
		time = 0;
		totaltime = 0;
		totalsubs = 0;
		maxSubscriptionCost = 0;
	}
		
	
	/**
	 * Adds a provider to the panel.
	 * 
	 * @param name
	 *            the name
	 * @param subcost
	 *            the subscription cost
	 */
	public void addProvider(String name, int subcost){
		int colorint = providers%colorlist.length;
		lines.add(new GraphLine(name,colorlist[colorint], 10, graphysize));
		providers++;	
		if(subcost>maxSubscriptionCost){maxSubscriptionCost=subcost;}	
	}
	
	/**
	 * Sets the total subscribers of this provider.
	 * 
	 * @param total
	 *            the total subscribers
	 */
	public void setTotalSubs(int total){
		totalsubs = total;
	}
	
	
	/**
	 * Adds the point to the graph.
	 * 
	 * @param time
	 *            the time
	 * @param provider
	 *            the provider
	 * @param revenue
	 *            the revenue
	 */
	public void addPoint(int provider, int time, int revenue){
		if(this.time!=time){this.time=time;}
		int x = 10 + (int)(time*timestep);
		int maxRev = maxSubscriptionCost*totalsubs*totaltime;
		
		double pct = ((double)revenue/maxRev);
		int y = graphysize-(int)(pct*(graphysize-10)); 
		
		lines.get(provider).addPoint(x, y);
	}
	
	
	
	/* (non-Javadoc)
	 * @see javax.swing.JComponent#paintComponent(java.awt.Graphics)
	 */
	public void paintComponent(Graphics comp){
		super.paintComponent(comp); 
		Graphics2D comp2D = (Graphics2D) comp; 
		comp2D.setColor(background); 
		comp2D.fillRect(0, 0, xsize, ysize); 

		comp2D.setColor(Color.black);
		float yf = Float.parseFloat(graphysize+"F");
		float xf = Float.parseFloat(graphxsize+"F");
		comp2D.draw(new Line2D.Float(10F,yf,xf+10F,yf));
		comp2D.draw(new Line2D.Float(10F,yf,10F,10F));

		comp2D.drawString("Total revenue", Float.parseFloat(((xsize/2)-30)+"F"), 20F);
		
		comp2D.drawString("TIME: "+time, Float.parseFloat(((xsize/2)-20)+"F"), 35F);
		if(totaltime!=0){
			int stepsize = (int)(((double)totaltime/10)*timestep);
			for(int i=1;i<11;i++){
				int xplace = 10+i*stepsize;
				float y1 = yf-5F;
				float y2 = yf+5F;
				Float xfl = Float.parseFloat(xplace+"F");
				comp2D.draw(new Line2D.Float(xfl,y1,xfl,y2));
				String timstr = ""+(int)(((double)totaltime/10)*i);
				Float xfl2 = Float.parseFloat((xplace-5)+"F");
				comp2D.drawString(timstr,xfl2 , yf-10F);
			}
		}
		
		if(totalsubs!=0){
			int stepsize = (graphysize-10)/10;
			for(int i=1;i<11;i++){
				int yplace = graphysize-i*stepsize;
				float yfl = Float.parseFloat(yplace+"F");
				float x1 = 5F;
				float x2 = 15F;
				comp2D.draw(new Line2D.Float(x1,yfl,x2,yfl));
				int maxRev = maxSubscriptionCost*totalsubs*totaltime;
				String subStr = (maxRev/10)*i+"";
				float yfl2 = Float.parseFloat((yplace+5)+"F");
				comp2D.drawString(subStr, 15F, yfl2);
			}
		}
		
		
		for(int i=0;i<lines.size();i++){
			GraphLine gl = lines.get(i);
			comp2D.setColor(gl.getColor());
			String namex = (graphxsize+20)+"F";
			int inty = i*15 + 20;
			String namey = inty+"F";
			comp2D.drawString(gl.getName(), Float.parseFloat(namex), Float.parseFloat(namey));
			ArrayList<Line2D.Float> lineList = gl.getLines();
			for(int j=0;j<lineList.size();j++){
				comp2D.draw(lineList.get(j));
			}
		}
		
		
	}
	

}
